# - Find Oyranos
# Find the native Oyranos headers and libraries.
#
#  OYRANOS_FOUND        - True if Oyranos found.
#  OYRANOS_INCLUDE_DIRS - where to find kdb.h, etc.
#  OYRANOS_LIBRARIES    - List of libraries when using Oyranos.
#
#  OYRANOS_VERSION       - The version of oyranos (x.y.z)
#  OYRANOS_VERSION_MAJOR - The major version of oyranos (x)
#  OYRANOS_VERSION_MINOR - The minor version of oyranos (y)
#  OYRANOS_VERSION_MICRO - The patch version of oyranos (z)
#



# Set path to the header file.
FIND_PATH(OYRANOS_INCLUDE_DIR
	NAMES oyranos.h
	PATHS /usr/include/oyranos
	NO_DEFAULT_PATH
)
MARK_AS_ADVANCED(OYRANOS_INCLUDE_DIR)


# Set path to the library.
FIND_LIBRARY(OYRANOS_CORE_LIBRARY
	NAMES oyranos_core  oyranos_core-static
	PATHS /usr/lib
	NO_DEFAULT_PATH
)
MARK_AS_ADVANCED(OYRANOS_CORE_LIBRARY)
FIND_LIBRARY(OYRANOS_OBJECT_LIBRARY
	NAMES oyranos_object oyranos_object-static
	PATHS /usr/lib
	NO_DEFAULT_PATH
)
MARK_AS_ADVANCED(OYRANOS_OBJECT_LIBRARY)
FIND_LIBRARY(OYRANOS_MODULES_LIBRARY
	NAMES oyranos_modules oyranos_modules-static
	PATHS /usr/lib
	NO_DEFAULT_PATH
)
MARK_AS_ADVANCED(OYRANOS_MODULES_LIBRARY)
FIND_LIBRARY(OYRANOS_CONFIG_LIBRARY
	NAMES oyranos_config oyranos_config-static
	PATHS /usr/lib
	NO_DEFAULT_PATH
)
MARK_AS_ADVANCED(OYRANOS_CONFIG_LIBRARY)
FIND_LIBRARY(OYRANOS_LIBRARY
	NAMES oyranos oyranos-static
	PATHS /usr/lib
	NO_DEFAULT_PATH
)
MARK_AS_ADVANCED(OYRANOS_LIBRARY)

# handle the QUIETLY and REQUIRED arguments and set OYRANOS_FOUND to TRUE if
# all listed variables are TRUE
INCLUDE(FindPackageHandleStandardArgs)
FIND_PACKAGE_HANDLE_STANDARD_ARGS(Oyranos DEFAULT_MSG OYRANOS_LIBRARY OYRANOS_INCLUDE_DIR)

if (OYRANOS_FOUND)
        SET( OYRANOS_VERSION_MAJOR 0 )
        SET( OYRANOS_VERSION_MINOR 9 )
        SET( OYRANOS_VERSION_MICRO 5 )
        SET( OYRANOS_VERSION 0.9.5 )
        SET( HAVE_OYRANOS TRUE )
	SET(OYRANOS_INCLUDE_DIRS ${OYRANOS_INCLUDE_DIR})
	SET(OYRANOS_LIBRARIES    ${OYRANOS_CORE_LIBRARY} ${OYRANOS_OBJECT_LIBRARY} ${OYRANOS_MODULES_LIBRARY} ${OYRANOS_CONFIG_LIBRARY} ${OYRANOS_LIBRARY} )
endif (OYRANOS_FOUND)
